@@ -1,18 +1,25 @@
 from __future__ import annotations
 
-from typing import Any, Optional, Union
+from typing import Any, Optional
 
 import ckan.plugins.toolkit as tk
 import ckan.model as model
 
 import ckanext.comments.const as const
+from ckanext.comments.model.thread import Subject
 from .model import Comment
 
 _helpers = {}
 
 
 def get_helpers():
-    return _helpers.copy()
+    helpers = _helpers.copy()
+
+    if 'csrf_input' not in tk.h:
+        helpers['csrf_input'] = lambda: ""
+
+    return helpers
+
 
 
 def helper(func):
@@ -24,7 +31,7 @@ def helper(func):
 @helper
 def thread_for(id_: Optional[str], type_: str) -> dict[str, Any]:
     thread = tk.get_action("comments_thread_show")(
-        None,
+        {},
         {
             "subject_id": id_,
             "subject_type": type_,
@@ -57,10 +64,15 @@ def author_of(id_: str) -> Optional[model.User]:
 
 
 @helper
-def subject_of(id_: str) -> Union[model.Package, None]:
+def subject_of(id_: str) -> Optional[Subject]:
     comment = (
         model.Session.query(Comment).filter(Comment.id == id_).one_or_none()
     )
     if not comment:
         return None
     return comment.thread.get_subject()
+
+
+@helper
+def enable_default_dataset_comments() -> bool:
+    return tk.asbool(tk.config.get(const.CONFIG_ENABLE_DATASET, const.DEFAULT_ENABLE_DATASET))
